@@ -42,7 +42,7 @@ struct byhandhook {
 };
 
 void byhandhooks_free(struct byhandhook *l) {
-	while( l != NULL ) {
+	while (l != NULL) {
 		/*@null@*/struct byhandhook *n = l->next;
 
 		free(l->sectionglob);
@@ -60,8 +60,10 @@ retvalue byhandhooks_parse(struct configiterator *iter, struct byhandhook **hook
 	struct byhandhook *h, *hooks = NULL, **nexthook_p = &hooks;
 
 	r = config_getwordinline(iter, &v);
-	if( RET_IS_OK(r) ) {
-		fprintf(stderr, "Error parsing %s, line %u, column %u: unexpected input '%s' (each hook must be in its own line)!\n",
+	if (RET_IS_OK(r)) {
+		fprintf(stderr,
+"Error parsing %s, line %u, column %u: unexpected input '%s'"
+" (each hook must be in its own line)!\n",
 				config_filename(iter),
 				config_markerline(iter),
 				config_markercolumn(iter),
@@ -69,16 +71,16 @@ retvalue byhandhooks_parse(struct configiterator *iter, struct byhandhook **hook
 		free(v);
 		r = RET_ERROR;
 	}
-	if( RET_WAS_ERROR(r) )
+	if (RET_WAS_ERROR(r))
 		return r;
-	while( config_nextline(iter) ) {
+	while (config_nextline(iter)) {
 		r = config_getwordinline(iter, &v);
-		if( r == RET_NOTHING )
+		if (r == RET_NOTHING)
 			continue;
-		if( RET_WAS_ERROR(r) )
+		if (RET_WAS_ERROR(r))
 			break;
-		h = calloc(1, sizeof(struct byhandhook));
-		if( FAILEDTOALLOC(h) ) {
+		h = zNEW(struct byhandhook);
+		if (FAILEDTOALLOC(h)) {
 			r = RET_ERROR_OOM;
 			break;
 		}
@@ -86,60 +88,64 @@ retvalue byhandhooks_parse(struct configiterator *iter, struct byhandhook **hook
 		nexthook_p = &h->next;
 		h->sectionglob = v;
 		r = config_getwordinline(iter, &v);
-		if( r == RET_NOTHING ) {
-			fprintf(stderr, "Error parsing %s, line %u, column %u: each byhand hooks needs 4 arguments, found only 1!\n",
+		if (r == RET_NOTHING) {
+			fprintf(stderr,
+"Error parsing %s, line %u, column %u: each byhand hooks needs 4 arguments, found only 1!\n",
 					config_filename(iter),
 					config_markerline(iter),
 					config_markercolumn(iter));
 			r = RET_ERROR;
 		}
-		if( RET_WAS_ERROR(r) )
+		if (RET_WAS_ERROR(r))
 			break;
 		h->priorityglob = v;
 		r = config_getwordinline(iter, &v);
-		if( r == RET_NOTHING ) {
-			fprintf(stderr, "Error parsing %s, line %u, column %u: each byhand hooks needs 4 arguments, found only 2!\n",
+		if (r == RET_NOTHING) {
+			fprintf(stderr,
+"Error parsing %s, line %u, column %u: each byhand hooks needs 4 arguments, found only 2!\n",
 					config_filename(iter),
 					config_markerline(iter),
 					config_markercolumn(iter));
 			r = RET_ERROR;
 		}
-		if( RET_WAS_ERROR(r) )
+		if (RET_WAS_ERROR(r))
 			break;
 		h->filenameglob = v;
 		r = config_getwordinline(iter, &v);
-		if( r == RET_NOTHING ) {
-			fprintf(stderr, "Error parsing %s, line %u, column %u: each byhand hooks needs 4 arguments, found only 2!\n",
+		if (r == RET_NOTHING) {
+			fprintf(stderr,
+"Error parsing %s, line %u, column %u: each byhand hooks needs 4 arguments, found only 2!\n",
 					config_filename(iter),
 					config_markerline(iter),
 					config_markercolumn(iter));
 			r = RET_ERROR;
 		}
-		if( RET_WAS_ERROR(r) )
+		if (RET_WAS_ERROR(r))
 			break;
-		assert( v != NULL && v[0] != '\0' ); \
-		if( v[0] != '/' ) {
+		assert (v != NULL && v[0] != '\0'); \
+		if (v[0] != '/') {
 			h->script = calc_dirconcat(global.confdir, v);
 			free(v);
-			if( h->script == NULL ) {
+			if (FAILEDTOALLOC(h->script)) {
 				r = RET_ERROR_OOM;
 				break;
 			}
 		} else
 			h->script = v;
 		r = config_getwordinline(iter, &v);
-		if( RET_IS_OK(r) ) {
-			fprintf(stderr, "Error parsing %s, line %u, column %u: each byhand hooks needs exactly 4 arguments, but there are more (first unexpected: '%s'!\n",
+		if (RET_IS_OK(r)) {
+			fprintf(stderr,
+"Error parsing %s, line %u, column %u: each byhand hooks needs exactly 4 arguments, but there are more (first unexpected: '%s'!\n",
 					config_filename(iter),
 					config_markerline(iter),
 					config_markercolumn(iter), v);
 			free(v);
 			r = RET_ERROR;
 		}
-		if( RET_WAS_ERROR(r) )
+		if (RET_WAS_ERROR(r))
 			break;
 	}
-	if( RET_WAS_ERROR(r) ) {
+	if (RET_WAS_ERROR(r)) {
 		byhandhooks_free(hooks);
 		return r;
 	}
@@ -152,15 +158,15 @@ bool byhandhooks_matched(const struct byhandhook *list, const struct byhandhook
 
 	/* for each file the first matching hook is called
 	 * it might later be extended to allow multiple with some keywords */
-	if( *touse != NULL )
-		/* if( (*touse)->nonexclusive ) list = (*touse)->next ; else */
+	if (*touse != NULL)
+		/* if ((*touse)->nonexclusive) list = (*touse)->next ; else */
 		return false;
-	for( h = list ; h != NULL ; h = h->next ) {
-		if( !globmatch(section, h->sectionglob) )
+	for (h = list ; h != NULL ; h = h->next) {
+		if (!globmatch(section, h->sectionglob))
 			continue;
-		if( !globmatch(priority, h->priorityglob) )
+		if (!globmatch(priority, h->priorityglob))
 			continue;
-		if( !globmatch(filename, h->filenameglob) )
+		if (!globmatch(filename, h->filenameglob))
 			continue;
 		*touse = h;
 		return true;
@@ -172,16 +178,16 @@ retvalue byhandhook_call(const struct byhandhook *h, const char *codename, const
 	pid_t child;
 
 	child = fork();
-	if( child == 0 ) {
+	if (child == 0) {
 		/* Try to close all open fd but 0,1,2 */
 		closefrom(3);
-		if( causingfile != NULL )
+		if (causingfile != NULL)
 			setenv("REPREPRO_CAUSING_FILE", causingfile, true);
 		else
 			unsetenv("REPREPRO_CAUSING_FILE");
-		if( atom_defined(causingcommand_atom) )
+		if (atom_defined(causingcommand))
 			setenv("REPREPRO_CAUSING_COMMAND",
-					atoms_commands[causingcommand_atom],
+					atoms_commands[causingcommand],
 					true);
 		else
 			unsetenv("REPREPRO_CAUSING_COMMAND");
@@ -201,19 +207,19 @@ retvalue byhandhook_call(const struct byhandhook *h, const char *codename, const
 		}
 		_exit(255);
 	}
-	if( child < 0 ) {
+	if (child < 0) {
 		int e = errno;
 		fprintf(stderr, "Error %d forking: %s!\n", e, strerror(e));
 		return RET_ERRNO(e);
 	}
-	while( true ) {
+	while (true) {
 		int status;
 		pid_t pid;
 
 		pid = waitpid(child, &status, 0);
-		if( pid == child ) {
-			if( WIFEXITED(status) ) {
-				if( WEXITSTATUS(status) == 0) {
+		if (pid == child) {
+			if (WIFEXITED(status)) {
+				if (WEXITSTATUS(status) == 0) {
 					return RET_OK;
 				}
 				fprintf(stderr,
@@ -222,7 +228,7 @@ retvalue byhandhook_call(const struct byhandhook *h, const char *codename, const
 					section, priority, name,
 					fullfilename,
 					(int)(WEXITSTATUS(status)));
-			} else if( WIFSIGNALED(status) ) {
+			} else if (WIFSIGNALED(status)) {
 				fprintf(stderr,
 "Byhandhook '%s' '%s' '%s' '%s' '%s' '%s' killed by signal %d!\n",
 					h->script, codename,
@@ -237,10 +243,10 @@ retvalue byhandhook_call(const struct byhandhook *h, const char *codename, const
 					fullfilename);
 			}
 			return RET_ERROR;
-		} else if( pid == (pid_t)-1 ) {
+		} else if (pid == (pid_t)-1) {
 			int e = errno;
 
-			if( e == EINTR )
+			if (e == EINTR)
 				continue;
 			fprintf(stderr,
 "Error %d calling waitpid on byhandhook child: %s\n",
