@@ -16,6 +16,9 @@ struct contentsoptions {
 		bool enabled:1;
 		bool udebs:1;
 		bool nodebs:1;
+		bool percomponent:1;
+		bool allcomponents:1;
+		bool compatsymlink:1;
 	} flags;
 	compressionset compressions;
 };
