@@ -681,6 +681,9 @@ static upgrade_decision ud_decide_by_rule(void *privdata, const struct target *t
 			return UD_NO;
 		case flt_warning:
 			return UD_LOUDNO;
+		case flt_supersede:
+			decision = UD_SUPERSEDE;
+			break;
 		case flt_hold:
 			decision = UD_HOLD;
 			break;
@@ -716,6 +719,9 @@ static upgrade_decision ud_decide_by_rule(void *privdata, const struct target *t
 		case flt_hold:
 			decision = UD_HOLD;
 			break;
+		case flt_supersede:
+			decision = UD_SUPERSEDE;
+			break;
 		case flt_error:
 			/* cannot yet be handled! */
 			fprintf(stderr,
@@ -745,6 +751,9 @@ static upgrade_decision ud_decide_by_rule(void *privdata, const struct target *t
 			case flt_hold:
 				decision = UD_HOLD;
 				break;
+			case flt_supersede:
+				decision = UD_SUPERSEDE;
+				break;
 			case flt_error:
 				/* cannot yet be handled! */
 				fprintf(stderr,
@@ -896,7 +905,7 @@ static void pull_dumppackage(const char *packagename, /*@null@*/const char *oldv
 					packagename, oldversion, bestcandidate);
 		} else if (oldversion != NULL) {
 			printf("'%s': '%s' will be deleted"
-					" (no longer available)\n",
+					" (no longer available or superseded)\n",
 					packagename, oldversion);
 		} else {
 			printf("'%s': will NOT be added as '%s'\n",
