@@ -24,8 +24,8 @@ void pull_freerules(/*@only@*/struct pull_rule *p);
 void pull_freedistributions(/*@only@*/struct pull_distribution *p);
 
 retvalue pull_prepare(struct distribution *, struct pull_rule *, bool fast, /*@out@*/struct pull_distribution **);
-retvalue pull_update(struct database *, struct pull_distribution *);
-retvalue pull_checkupdate(struct database *, struct pull_distribution *);
-retvalue pull_dumpupdate(struct database *, struct pull_distribution *);
+retvalue pull_update(struct pull_distribution *);
+retvalue pull_checkupdate(struct pull_distribution *);
+retvalue pull_dumpupdate(struct pull_distribution *);
 
 #endif
