@@ -463,12 +463,7 @@ retvalue target_addpackage(struct target *target, struct logger *logger, const c
 				if (versioncmp <= 0) {
 					/* new Version is not newer than
 					 * old version */
-					if (downgrade) {
-						fprintf(stderr,
-"Warning: downgrading '%s' from '%s' to '%s' in '%s'!\n", name,
-							oldpversion, version,
-							target->identifier);
-					} else {
+					if (!downgrade) {
 						fprintf(stderr,
 "Skipping inclusion of '%s' '%s' in '%s', as it has already '%s'.\n",
 							name, version,
@@ -477,6 +472,16 @@ retvalue target_addpackage(struct target *target, struct logger *logger, const c
 						free(oldpversion);
 						free(oldcontrol);
 						return RET_NOTHING;
+					} else if (versioncmp < 0) {
+						fprintf(stderr,
+"Warning: downgrading '%s' from '%s' to '%s' in '%s'!\n", name,
+							oldpversion, version,
+							target->identifier);
+					} else {
+						fprintf(stderr,
+"Warning: replacing '%s' version '%s' with equal version '%s' in '%s'!\n", name,
+							oldpversion, version,
+							target->identifier);
 					}
 				}
 			}
@@ -838,6 +843,69 @@ retvalue target_reoverride(struct target *target, struct distribution *distribut
 	return result;
 }
 
+/* Readd checksum information */
+
+static retvalue complete_package_checksums(struct target *target, const char *control, char **n) {
+	struct checksumsarray files;
+	retvalue r;
+
+	r = target->getchecksums(control, &files);
+	if (!RET_IS_OK(r))
+		return r;
+
+	r = files_checkorimprove(&files.names, files.checksums);
+	if (!RET_IS_OK(r)) {
+		checksumsarray_done(&files);
+		return r;
+	}
+	r = target->completechecksums(control,
+			&files.names, files.checksums, n);
+	checksumsarray_done(&files);
+	return r;
+}
+
+retvalue target_redochecksums(struct target *target, struct distribution *distribution) {
+	struct target_cursor iterator;
+	retvalue result, r;
+	const char *package, *controlchunk;
+
+	assert(target->packages == NULL);
+	assert(distribution != NULL);
+
+	if (verbose > 1) {
+		fprintf(stderr,
+"Redoing checksum information for packages in '%s'...\n",
+				target->identifier);
+	}
+
+	r = target_openiterator(target, READWRITE, &iterator);
+	if (!RET_IS_OK(r))
+		return r;
+	result = RET_NOTHING;
+	while (target_nextpackage(&iterator, &package, &controlchunk)) {
+		char *newcontrolchunk = NULL;
+
+		r = complete_package_checksums(target, controlchunk,
+				&newcontrolchunk);
+		RET_UPDATE(result, r);
+		if (RET_WAS_ERROR(r))
+			break;
+		if (RET_IS_OK(r)) {
+			r = cursor_replace(target->packages, iterator.cursor,
+				newcontrolchunk, strlen(newcontrolchunk));
+			free(newcontrolchunk);
+			if (RET_WAS_ERROR(r)) {
+				result = r;
+				break;
+			}
+			target->wasmodified = true;
+		}
+	}
+	r = target_closeiterator(&iterator);
+	RET_ENDUPDATE(result, r);
+	return result;
+}
+
 /* export a database */
 
 retvalue target_export(struct target *target, bool onlyneeded, bool snapshot, struct release *release) {
